@@ -1,10 +1,12 @@
 from pathlib import Path
 from unittest import mock
-import responses # type: ignore
+import responses  # type: ignore
 import json
 import gzip
 from tests.cli_test_case import CliTestCase
 from launchable.utils.http_client import get_base_url
+import tempfile
+from tests.helper import ignore_warnings
 
 
 class GradleTest(CliTestCase):
@@ -22,6 +24,23 @@ class GradleTest(CliTestCase):
         output = '--tests com.launchableinc.rocket_car_gradle.AppTest2 --tests com.launchableinc.rocket_car_gradle.AppTest --tests com.launchableinc.rocket_car_gradle.sub.AppTest3 --tests com.launchableinc.rocket_car_gradle.utils.UtilsTest'
         self.assertEqual(result.output.rstrip('\n'), output)
 
+    @ignore_warnings
+    @responses.activate
+    def test_subset_rest(self):
+        responses.replace(responses.POST, "{}/intake/organizations/{}/workspaces/{}/subset".format(get_base_url(), self.organization, self.workspace),
+                          json={'testPaths': [[{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.AppTest2'}], [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.AppTest'}], [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.utils.UtilsTest'}]]}, status=200)
+
+        rest = tempfile.NamedTemporaryFile()
+
+        result = self.cli('subset', '--target', '10%', '--build',
+                          self.build_name, '--rest', rest.name, 'gradle', str(self.test_files_dir.joinpath('java/app/src/test/java').resolve()))
+
+        self.assertEqual(result.exit_code, 0)
+        self.assertEqual(result.output.rstrip(
+            '\n'), "--tests com.launchableinc.rocket_car_gradle.AppTest2 --tests com.launchableinc.rocket_car_gradle.AppTest --tests com.launchableinc.rocket_car_gradle.utils.UtilsTest")
+        self.assertEqual(rest.read().decode(
+        ), '--tests com.launchableinc.rocket_car_gradle.sub.AppTest3')
+
     @responses.activate
     def test_record_test_gradle(self):
         result = self.cli('record', 'tests',  '--session', self.session,
